/* Tokenizer
 * Copyright 2009 Jetro Lauha
 *
 * Utility class to tokenize strings.
 * Inspired by "tokenwad" by Jari Komppa.
 *
 * My home page / blog URL:
 *   http://jet.ro
 *
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any damages
 * arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software
 *    in a product, an acknowledgment in the product documentation would be
 *    appreciated but is not required.
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 * 3. This notice may not be removed or altered from any source distribution.
 *
 * $Id: Tokenizer.h 89 2009-11-08 23:43:41Z tonic $
 * $Revision: 89 $
 */

#ifndef TOKENIZER_H_INCLUDED
#define TOKENIZER_H_INCLUDED


class Tokenizer
{
public:
    Tokenizer(bool trimWhitespace = true);
    ~Tokenizer();

    // Resets/reconfigures state of the tokenizer (frees up any internally used memory).
    void clear(bool trimWhitespace = true);

    // Tokenizes string by the given separators. Creates a private copy of the data.
    // Returns true when successful, or false if tokenization failed for some reason.
    bool tokenize(const char *str, const char *separators);
    // Tokenizes string in-place by the given separators, destroying the original content.
    // Returns true when successful, or false if tokenization failed for some reason.
    bool tokenizeInPlace(char *str, const char *separators);

    // Returns count of tokens, or 0 if tokenizer hasn't been run yet.
    int count() const { return mCount; }

    // Returns token by index, or 0 if no token with such index exists.
    char * get(int index) const { return (index >= 0 && index < mCount) ? mTokens[index] : 0; }

    // Returns token as integer, or given default value if it can't be converted.
    int getAsInt(int index, int defaultValue = -1);

    // Returns true if token with given index equals given string, or false otherwise.
    bool equals(int index, const char *str);

    // Returns true if token with given index equals given string case insensitively, or false otherwise.
    bool equalsIgnoreCase(int index, const char *str);


private:

    bool internalTokenize(char *str, const char *separators);

    bool mTrim;
    int mCount;
    char *mCopy;
    char **mTokens;
};


#endif // !TOKENIZER_H_INCLUDED
