/* tokenizer_test
 * Copyright 2009 Jetro Lauha
 *
 * Small set of unit tests for the Tokenizer class.
 *
 *
 * My home page / blog URL:
 *   http://jet.ro
 *
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any damages
 * arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software
 *    in a product, an acknowledgment in the product documentation would be
 *    appreciated but is not required.
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 * 3. This notice may not be removed or altered from any source distribution.
 *
 * $Id: tokenizer_test.cpp 96 2009-11-09 20:39:09Z tonic $
 * $Revision: 96 $
 */

#include <stdlib.h>
#include <string.h>
#include <stdio.h>

#include "Tokenizer.h"


bool gResult = true;


void test(const char *testStr, bool result)
{
    printf("test: %s; %s\n", result ? "pass" : "FAIL", testStr);
    gResult &= result;
}


#define TEST(x) test(#x, x)


int main(int, char *[])
{
    Tokenizer t(false);

    t.tokenize(" foo bar Gorp ", " ");
    TEST(t.count() == 5);
    TEST(t.equals(0, ""));
    TEST(t.equals(1, "foo"));
    TEST(t.equalsIgnoreCase(2, "bAR"));
    TEST(t.equalsIgnoreCase(3, "GORP"));
    TEST(!t.equals(2, "BAR"));
    TEST(t.equals(4, ""));

    t.clear(true);
    TEST(t.count() == 0);

    char foo[] = "x=3, y= -4, z = q ";
    // fooRes is what foo should end up like after in-place tokenizing...
    const char fooRes[] = "x\0" "3\0 y\0 -4\0 z\0\0 q\0";
    t.tokenizeInPlace(foo, ",");
    TEST(t.count() == 3);
    {
        Tokenizer t2;
        t2.tokenizeInPlace(t.get(0), "=");
        TEST(t2.count() == 2);
        TEST(t2.equals(0, "x"));
        TEST(t2.getAsInt(1) == 3);
        t2.tokenizeInPlace(t.get(1), "=");
        TEST(t2.count() == 2);
        TEST(t2.get(0)[0]== 'y');
        TEST(t2.getAsInt(1) == -4);
        t2.tokenizeInPlace(t.get(2), "=");
        TEST(t2.count() == 2);
        TEST(strlen(t2.get(0)) == 1);
        TEST(strlen(t2.get(1)) == 1);
        TEST(t2.getAsInt(1, 55) == 55);
    }

    TEST(strlen(foo) == 1);
    TEST(memcmp(foo, fooRes, sizeof(fooRes)) == 0);
    printf("in-place destroyed string: foo:%s\n", foo);

    printf("\nFinal result: %s\n\n", gResult ? "pass" : "FAIL");
    
    return EXIT_SUCCESS;
}
